==> status-4-evar_0.2011.11.13.22.orig.tar.bz2: status-4-evar-0.2011.11.13.22/defaults/preferences/defaults.js <==
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Status-4-Evar.
 *
 * The Initial Developer of the Original Code is 
 * Matthew Turnbull <sparky@bluefang-logic.com>.
 *
 * Portions created by the Initial Developer are Copyright (C) 2011
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 * 
 * ***** END LICENSE BLOCK ***** */

pref("status4evar.addonbar.borderStyle", false);
pref("status4evar.addonbar.closeButton", false);
pref("status4evar.addonbar.windowGripper", true);

pref("status4evar.download.color.active", "#33FF33");
pref("status4evar.download.color.paused", "#808080");
pref("status4evar.download.force", false);
pref("status4evar.download.label", 0);
pref("status4evar.download.label.force", true);
pref("status4evar.download.progress", 1);
pref("status4evar.download.tooltip", 1);

pref("status4evar.firstRun", true);

//pref("status4evar.progress.tab", 1);
//pref("status4evar.progress.tab.css", "#33FF33");
//pref("status4evar.progress.tab.style", true);

pref("status4evar.progress.toolbar.css", "#33FF33");
pref("status4evar.progress.toolbar.force", false);
pref("status4evar.progress.toolbar.style", false);
pref("status4evar.progress.toolbar.style.advanced", false);

pref("status4evar.progress.urlbar", 1);
pref("status4evar.progress.urlbar.css", "#33FF33");
pref("status4evar.progress.urlbar.style", true);
pref("status4evar.progress.urlbar.style.advanced", false);

pref("status4evar.status", 1);
pref("status4evar.status.default", true);
pref("status4evar.status.network", true);
pref("status4evar.status.network.xhr", true);
pref("status4evar.status.timeout", 0);
pref("status4evar.status.linkOver", 1);
pref("status4evar.status.linkOver.delay.show", 70);
pref("status4evar.status.linkOver.delay.hide", 150);

pref("status4evar.status.toolbar.maxLength", 0);

pref("status4evar.status.urlbar.align", 0);
pref("status4evar.status.urlbar.color", "GrayText");
pref("status4evar.status.urlbar.position", 33);

pref("status4evar.status.popup.findMirror", true);
pref("status4evar.status.popup.invertMirror", false);
pref("status4evar.status.popup.mouseMirror", true);

==> status-4-evar_0.2012.04.21.13.orig.tar.bz2: status-4-evar-0.2012.04.21.13/defaults/preferences/defaults.js <==
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Status-4-Evar.
 *
 * The Initial Developer of the Original Code is 
 * Matthew Turnbull <sparky@bluefang-logic.com>.
 *
 * Portions created by the Initial Developer are Copyright (C) 2011
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 * 
 * ***** END LICENSE BLOCK ***** */

pref("status4evar.addonbar.borderStyle", false);
pref("status4evar.addonbar.closeButton", false);
pref("status4evar.addonbar.windowGripper", true);

pref("status4evar.advanced.showWarning", true);
pref("status4evar.advanced.urlbar.forceBinding", false);

pref("status4evar.download.color.active", "#33FF33");
pref("status4evar.download.color.paused", "#808080");
pref("status4evar.download.force", false);
pref("status4evar.download.label", 0);
pref("status4evar.download.label.force", true);
pref("status4evar.download.progress", 1);
pref("status4evar.download.tooltip", 1);

pref("status4evar.firstRun", true);

//pref("status4evar.progress.tab", 1);
//pref("status4evar.progress.tab.css", "#33FF33");
//pref("status4evar.progress.tab.style", true);

pref("status4evar.progress.toolbar.css", "#33FF33");
pref("status4evar.progress.toolbar.force", false);
pref("status4evar.progress.toolbar.style", false);
pref("status4evar.progress.toolbar.style.advanced", false);

pref("status4evar.progress.urlbar", 1);
pref("status4evar.progress.urlbar.css", "#33FF33");
pref("status4evar.progress.urlbar.style", true);
pref("status4evar.progress.urlbar.style.advanced", false);

pref("status4evar.status", 1);
pref("status4evar.status.default", true);
pref("status4evar.status.network", true);
pref("status4evar.status.network.xhr", true);
pref("status4evar.status.timeout", 0);
pref("status4evar.status.linkOver", 1);
pref("status4evar.status.linkOver.delay.show", 70);
pref("status4evar.status.linkOver.delay.hide", 150);

pref("status4evar.status.toolbar.maxLength", 0);

pref("status4evar.status.urlbar.align", 0);
pref("status4evar.status.urlbar.color", "GrayText");
pref("status4evar.status.urlbar.position", 33);

pref("status4evar.status.popup.findMirror", true);
pref("status4evar.status.popup.invertMirror", false);
pref("status4evar.status.popup.mouseMirror", true);
